@@ -5,6 +5,7 @@ import os
 import requests
 import shutil
 import time
+import traceback
 
 
 def jobj(obj) -> str:
@@ -297,8 +298,9 @@ class Retry(object):
                 result = self._func(*self._args)
                 break
             except Exception as e:
+                traceback.print_exc()  # 输出调用信息
                 if self._retry == 0:
-                    print("Retry failed, error: %s" % e)
+                    print("[Retry]Retry failed, error: %s" % e)
                     break
             time.sleep(self._delay)
             self._retry = self._retry - 1
